@@ -112,12 +112,14 @@ int fuse_loop_mt(struct fuse *f)
   if (f == NULL)
     return -1;
 
-  int res = fuse_start_cleanup_thread(f);
+  int res = fuse_start_maintenance_thread(f);
   if (res)
     return -1;
 
   res = fuse_session_loop_mt(fuse_get_session(f),
                              fuse_config_num_threads(f));
-  fuse_stop_cleanup_thread(f);
+
+  fuse_stop_maintenance_thread(f);
+
   return res;
 }
