@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __ASSERT_HPP__
-#define __ASSERT_HPP__
+#pragma once
 
 #define STATIC_ASSERT(cond) assert::StaticAssert< (cond) >()
 #define STATIC_ARRAYLENGTH_ASSERT(array,size) STATIC_ASSERT(((sizeof(array)/sizeof(array[0]))==(size)))
@@ -29,5 +28,3 @@ namespace assert
   struct StaticAssert<true>
   {};
 }
-
-#endif
