@@ -18,10 +18,12 @@
 
 #pragma once
 
+#include <cstdint>
+
 #include <stddef.h>
-#include <stdint.h>
 #include <sys/types.h>
 
+
 namespace fs
 {
   int64_t
