@@ -18,7 +18,8 @@
 #include "fs_copy_file_range.hpp"
 #include "fs_fstat.hpp"
 
-#include <stdint.h>
+#include <cstdint>
+
 
 namespace l
 {
