@@ -16,8 +16,9 @@
 
 #pragma once
 
+
 namespace FUSE
 {
   void
-  destroy(void *);
+  destroy(void);
 }
