@@ -20,7 +20,8 @@
 #include "fs_fstat.hpp"
 #include "fs_inode.hpp"
 
-#include <fuse.h>
+#include "fuse.h"
+
 
 namespace l
 {
@@ -50,15 +51,15 @@ namespace FUSE
            fuse_timeouts_t        *timeout_)
   {
     int rv;
-    const Config &config = Config::ro();
+    Config::Read cfg;
     FileInfo *fi = reinterpret_cast<FileInfo*>(ffi_->fh);
 
     rv = l::fgetattr(fi->fd,fi->fusepath,st_);
 
     timeout_->entry = ((rv >= 0) ?
-                       config.cache_entry :
-                       config.cache_negative_entry);
-    timeout_->attr  = config.cache_attr;
+                       cfg->cache_entry :
+                       cfg->cache_negative_entry);
+    timeout_->attr  = cfg->cache_attr;
 
     return rv;
   }
