@@ -19,7 +19,8 @@
 #include "fs_close.hpp"
 #include "fs_dup.hpp"
 
-#include <fuse.h>
+#include "fuse.h"
+
 
 namespace l
 {
