@@ -19,11 +19,12 @@
 #include "fs_fdatasync.hpp"
 #include "fs_fsync.hpp"
 
-#include <fuse.h>
+#include "fuse.h"
 
 #include <string>
 #include <vector>
 
+
 namespace l
 {
   static
