@@ -19,19 +19,55 @@
 #include "fs_inode.hpp"
 #include "fs_lstat.hpp"
 #include "fs_path.hpp"
+#include "fs_stat.hpp"
 #include "symlinkify.hpp"
 #include "ugid.hpp"
 
-#include <fuse.h>
+#include "fuse.h"
 
 #include <string>
-#include <vector>
 
 using std::string;
-using std::vector;
+
 
 namespace l
 {
+  static
+  void
+  set_stat_if_leads_to_dir(const std::string &path_,
+                           struct stat       *st_)
+  {
+    int rv;
+    struct stat st;
+
+    rv = fs::stat(path_,&st);
+    if(rv == -1)
+      return;
+
+    if(S_ISDIR(st.st_mode))
+      *st_ = st;
+
+    return;
+  }
+
+  static
+  void
+  set_stat_if_leads_to_reg(const std::string &path_,
+                           struct stat       *st_)
+  {
+    int rv;
+    struct stat st;
+
+    rv = fs::stat(path_,&st);
+    if(rv == -1)
+      return;
+
+    if(S_ISREG(st.st_mode))
+      *st_ = st;
+
+    return;
+  }
+
   static
   int
   getattr_controlfile(struct stat *st_)
@@ -59,16 +95,17 @@ namespace l
 
   static
   int
-  getattr(Policy::Func::Search  searchFunc_,
+  getattr(const Policy::Search &searchFunc_,
           const Branches       &branches_,
           const char           *fusepath_,
           struct stat          *st_,
           const bool            symlinkify_,
-          const time_t          symlinkify_timeout_)
+          const time_t          symlinkify_timeout_,
+          FollowSymlinks        followsymlinks_)
   {
     int rv;
     string fullpath;
-    vector<string> basepaths;
+    StrVec basepaths;
 
     rv = searchFunc_(branches_,fusepath_,&basepaths);
     if(rv == -1)
@@ -76,7 +113,28 @@ namespace l
 
     fullpath = fs::path::make(basepaths[0],fusepath_);
 
-    rv = fs::lstat(fullpath,st_);
+    switch(followsymlinks_)
+      {
+      case FollowSymlinks::ENUM::NEVER:
+        rv = fs::lstat(fullpath,st_);
+        break;
+      case FollowSymlinks::ENUM::DIRECTORY:
+        rv = fs::lstat(fullpath,st_);
+        if(S_ISLNK(st_->st_mode))
+          l::set_stat_if_leads_to_dir(fullpath,st_);
+        break;
+      case FollowSymlinks::ENUM::REGULAR:
+        rv = fs::lstat(fullpath,st_);
+        if(S_ISLNK(st_->st_mode))
+          l::set_stat_if_leads_to_reg(fullpath,st_);
+        break;
+      case FollowSymlinks::ENUM::ALL:
+        rv = fs::stat(fullpath,st_);
+        if(rv != 0)
+          rv = fs::lstat(fullpath,st_);
+        break;
+      }
+
     if(rv == -1)
       return -errno;
 
@@ -87,6 +145,32 @@ namespace l
 
     return 0;
   }
+
+  int
+  getattr(const char      *fusepath_,
+          struct stat     *st_,
+          fuse_timeouts_t *timeout_)
+  {
+    int rv;
+    Config::Read cfg;
+    const fuse_context *fc = fuse_get_context();
+    const ugid::Set     ugid(fc->uid,fc->gid);
+
+    rv = l::getattr(cfg->func.getattr.policy,
+                    cfg->branches,
+                    fusepath_,
+                    st_,
+                    cfg->symlinkify,
+                    cfg->symlinkify_timeout,
+                    cfg->follow_symlinks);
+
+    timeout_->entry = ((rv >= 0) ?
+                       cfg->cache_entry :
+                       cfg->cache_negative_entry);
+    timeout_->attr  = cfg->cache_attr;
+
+    return rv;
+  }
 }
 
 namespace FUSE
@@ -96,27 +180,9 @@ namespace FUSE
           struct stat     *st_,
           fuse_timeouts_t *timeout_)
   {
-    int rv;
-    const Config &config = Config::ro();
-
-    if(fusepath_ == config.controlfile)
+    if(fusepath_ == CONTROLFILE)
       return l::getattr_controlfile(st_);
 
-    const fuse_context *fc = fuse_get_context();
-    const ugid::Set     ugid(fc->uid,fc->gid);
-
-    rv = l::getattr(config.func.getattr.policy,
-                    config.branches,
-                    fusepath_,
-                    st_,
-                    config.symlinkify,
-                    config.symlinkify_timeout);
-
-    timeout_->entry = ((rv >= 0) ?
-                       config.cache_entry :
-                       config.cache_negative_entry);
-    timeout_->attr  = config.cache_attr;
-
-    return rv;
+    return l::getattr(fusepath_,st_,timeout_);
   }
 }
