@@ -27,8 +27,6 @@
 #include "str.hpp"
 #include "ugid.hpp"
 
-#include <fuse.h>
-
 #include <string>
 #include <vector>
 
@@ -38,17 +36,13 @@
 using std::string;
 using std::vector;
 
-typedef char IOCTL_BUF[4096];
-#define IOCTL_APP_TYPE 0xDF
-//#define IOCTL_READ_KEYS 0xD000DF00
-//#define IOCTL_READ_VAL  0xD000DF01
-//#define IOCTL_WRITE_VAL 0x5000DF02
-//#define IOCTL_FILE_INFO 0xD000DF03
-#define IOCTL_READ_KEYS _IOWR(IOCTL_APP_TYPE,0,IOCTL_BUF)
-#define IOCTL_READ_VAL  _IOWR(IOCTL_APP_TYPE,1,IOCTL_BUF)
-#define IOCTL_WRITE_VAL _IOW(IOCTL_APP_TYPE,2,IOCTL_BUF)
-#define IOCTL_FILE_INFO _IOWR(IOCTL_APP_TYPE,3,IOCTL_BUF)
+#ifndef _IOC_TYPE
+#define _IOC_TYPE(X) (((X) >> 8) & 0xFF)
+#endif
 
+typedef char IOCTL_BUF[4096];
+#define IOCTL_APP_TYPE  0xDF
+#define IOCTL_FILE_INFO _IOWR(IOCTL_APP_TYPE,0,IOCTL_BUF)
 
 #ifndef FS_IOC_GETFLAGS
 # define FS_IOC_GETFLAGS _IOR('f',1,long)
@@ -134,7 +128,7 @@ namespace l
 
   static
   int
-  ioctl_dir_base(Policy::Func::Search  searchFunc_,
+  ioctl_dir_base(const Policy::Search &searchFunc_,
                  const Branches       &branches_,
                  const char           *fusepath_,
                  const uint32_t        cmd_,
@@ -144,7 +138,7 @@ namespace l
     int fd;
     int rv;
     string fullpath;
-    vector<string> basepaths;
+    StrVec basepaths;
 
     rv = searchFunc_(branches_,fusepath_,&basepaths);
     if(rv == -1)
@@ -170,13 +164,13 @@ namespace l
             void                   *data_,
             uint32_t               *out_bufsz_)
   {
-    DirInfo            *di     = reinterpret_cast<DirInfo*>(ffi_->fh);
-    const fuse_context *fc     = fuse_get_context();
-    const Config       &config = Config::ro();
+    Config::Read        cfg;
+    DirInfo            *di = reinterpret_cast<DirInfo*>(ffi_->fh);
+    const fuse_context *fc = fuse_get_context();
     const ugid::Set     ugid(fc->uid,fc->gid);
 
-    return l::ioctl_dir_base(config.func.open.policy,
-                             config.branches,
+    return l::ioctl_dir_base(cfg->func.open.policy,
+                             cfg->branches,
                              di->fusepath.c_str(),
                              cmd_,
                              data_,
@@ -201,65 +195,13 @@ namespace l
 
   static
   int
-  read_keys(void *data_)
-  {
-    std::string   keys;
-    const Config &config = Config::ro();
-
-    config.keys(keys);
-
-    return l::strcpy(keys,data_);
-  }
-
-  static
-  int
-  read_val(void *data_)
-  {
-    int rv;
-    char *data;
-    std::string key;
-    std::string val;
-    const Config &config = Config::ro();
-
-    data = (char*)data_;
-    data[sizeof(IOCTL_BUF) - 1] = '\0';
-
-    key = data;
-    rv = config.get(key,&val);
-    if(rv < 0)
-      return rv;
-
-    return l::strcpy(val,data_);
-  }
-
-  static
-  int
-  write_val(void *data_)
-  {
-    char *data;
-    std::string kv;
-    std::string key;
-    std::string val;
-    Config &config = Config::rw();
-
-    data = (char*)data_;
-    data[sizeof(IOCTL_BUF) - 1] = '\0';
-
-    kv = data;
-    str::splitkv(kv,'=',&key,&val);
-
-    return config.set(key,val);
-  }
-
-  static
-  int
-  file_basepath(Policy::Func::Search  searchFunc_,
+  file_basepath(const Policy::Search &searchFunc_,
                 const Branches       &branches_,
                 const char           *fusepath_,
                 void                 *data_)
   {
     int rv;
-    vector<string> basepaths;
+    StrVec basepaths;
 
     rv = searchFunc_(branches_,fusepath_,&basepaths);
     if(rv == -1)
@@ -273,11 +215,11 @@ namespace l
   file_basepath(const fuse_file_info_t *ffi_,
                 void                   *data_)
   {
-    const Config &config   = Config::ro();
+    Config::Read cfg;
     std::string  &fusepath = reinterpret_cast<FH*>(ffi_->fh)->fusepath;
 
-    return l::file_basepath(config.func.open.policy,
-                            config.branches,
+    return l::file_basepath(cfg->func.open.policy,
+                            cfg->branches,
                             fusepath.c_str(),
                             data_);
   }
@@ -294,14 +236,14 @@ namespace l
 
   static
   int
-  file_fullpath(Policy::Func::Search  searchFunc_,
+  file_fullpath(const Policy::Search &searchFunc_,
                 const Branches       &branches_,
                 const string         &fusepath_,
                 void                 *data_)
   {
     int rv;
     string fullpath;
-    vector<string> basepaths;
+    StrVec basepaths;
 
     rv = searchFunc_(branches_,fusepath_,&basepaths);
     if(rv == -1)
@@ -317,11 +259,11 @@ namespace l
   file_fullpath(const fuse_file_info_t *ffi_,
                 void                   *data_)
   {
-    const Config &config   = Config::ro();
+    Config::Read cfg;
     std::string  &fusepath = reinterpret_cast<FH*>(ffi_->fh)->fusepath;
 
-    return l::file_fullpath(config.func.open.policy,
-                            config.branches,
+    return l::file_fullpath(cfg->func.open.policy,
+                            cfg->branches,
                             fusepath,
                             data_);
   }
@@ -331,13 +273,13 @@ namespace l
   file_allpaths(const fuse_file_info_t *ffi_,
                 void                   *data_)
   {
+    Config::Read cfg;
     string concated;
-    vector<string> paths;
-    vector<string> branches;
+    StrVec paths;
+    StrVec branches;
     string &fusepath = reinterpret_cast<FH*>(ffi_->fh)->fusepath;
-    const Config &config = Config::ro();
 
-    config.branches.to_paths(branches);
+    cfg->branches->to_paths(branches);
 
     fs::findallfiles(branches,fusepath.c_str(),&paths);
 
@@ -364,6 +306,28 @@ namespace l
 
     return -ENOATTR;
   }
+
+  static
+  bool
+  is_mergerfs_ioctl_cmd(const unsigned long cmd_)
+  {
+    return (_IOC_TYPE(cmd_) == IOCTL_APP_TYPE);
+  }
+
+  static
+  int
+  ioctl_custom(const fuse_file_info_t *ffi_,
+               unsigned long           cmd_,
+               void                   *data_)
+  {
+    switch(cmd_)
+      {
+      case IOCTL_FILE_INFO:
+        return l::file_info(ffi_,data_);
+      }
+
+    return -ENOTTY;
+  }
 }
 
 namespace FUSE
@@ -376,17 +340,8 @@ namespace FUSE
         void                   *data_,
         uint32_t               *out_bufsz_)
   {
-    switch(cmd_)
-      {
-      case IOCTL_READ_KEYS:
-        return l::read_keys(data_);
-      case IOCTL_READ_VAL:
-        return l::read_val(data_);
-      case IOCTL_WRITE_VAL:
-        return l::write_val(data_);
-      case IOCTL_FILE_INFO:
-        return l::file_info(ffi_,data_);
-      }
+    if(l::is_mergerfs_ioctl_cmd(cmd_))
+      return l::ioctl_custom(ffi_,cmd_,data_);
 
     if(flags_ & FUSE_IOCTL_DIR)
       return l::ioctl_dir(ffi_,cmd_,data_,out_bufsz_);
