@@ -18,16 +18,17 @@
 
 #pragma once
 
-#include "branch.hpp"
+#include "branches.hpp"
 
-#include <fuse.h>
+#include "fuse.h"
+
+#include <cstdint>
 
-#include <stdint.h>
 
 namespace FUSE
 {
   int
-  readdir_linux(const Branches &branches,
-                const char     *dirname,
-                fuse_dirents_t *buf);
+  readdir_linux(const Branches::CPtr &branches,
+                const char           *dirname,
+                fuse_dirents_t       *buf);
 }
