@@ -20,7 +20,7 @@
 #include "fs_unlink.hpp"
 #include "ugid.hpp"
 
-#include <fuse.h>
+#include "fuse.h"
 
 #include <string>
 #include <vector>
@@ -84,14 +84,14 @@ namespace l
 
   static
   int
-  unlink(Policy::Func::Action  actionFunc_,
+  unlink(const Policy::Action &unlinkPolicy_,
          const Branches       &branches_,
          const char           *fusepath_)
   {
     int rv;
     vector<string> basepaths;
 
-    rv = actionFunc_(branches_,fusepath_,&basepaths);
+    rv = unlinkPolicy_(branches_,fusepath_,&basepaths);
     if(rv == -1)
       return -errno;
 
@@ -104,14 +104,12 @@ namespace FUSE
   int
   unlink(const char *fusepath_)
   {
-    const fuse_context *fc     = fuse_get_context();
-    const Config       &config = Config::ro();
+    Config::Read cfg;
+    const fuse_context *fc = fuse_get_context();
     const ugid::Set     ugid(fc->uid,fc->gid);
 
-    config.open_cache.erase(fusepath_);
-
-    return l::unlink(config.func.unlink.policy,
-                     config.branches,
+    return l::unlink(cfg->func.unlink.policy,
+                     cfg->branches,
                      fusepath_);
   }
 }
