@@ -16,10 +16,11 @@
 
 #pragma once
 
-#include <fuse.h>
+#include "fuse.h"
 
 #include <sys/types.h>
 
+
 namespace FUSE
 {
   int
