@@ -19,7 +19,7 @@
 #pragma once
 
 #include "khash.h"
-#include "fasthash.h"
+#include "wyhash.h"
 
 KHASH_SET_INIT_INT64(hashset);
 
@@ -38,13 +38,14 @@ public:
 
   inline
   int
-  put(const char *str_)
+  put(const char     *str_,
+      const uint64_t  len_)
   {
     int rv;
     uint64_t h;
     khint_t key;
 
-    h = fasthash64(str_,strlen(str_),0x7472617065786974);
+    h = wyhash(str_,len_,0x7472617065786974,_wyp);
 
     key = kh_put(hashset,_set,h,&rv);
     if(rv == 0)
@@ -55,6 +56,13 @@ public:
     return rv;
   }
 
+  inline
+  int
+  put(const char *str_)
+  {
+    return put(str_,strlen(str_));
+  }
+
   inline
   int
   size(void)
