@@ -18,23 +18,23 @@
 #include "fs_exists.hpp"
 #include "fs_info.hpp"
 #include "fs_path.hpp"
+#include "policies.hpp"
 #include "policy.hpp"
 #include "policy_error.hpp"
-#include "rwlock.hpp"
+#include "policy_lfs.hpp"
+#include "strvec.hpp"
 
 #include <limits>
 #include <string>
-#include <vector>
 
 using std::string;
-using std::vector;
 
 namespace lfs
 {
   static
   int
-  create(const BranchVec &branches_,
-         vector<string>  *paths_)
+  create(const Branches::CPtr &branches_,
+         StrVec               *paths_)
   {
     int rv;
     int error;
@@ -46,24 +46,22 @@ namespace lfs
     error = ENOENT;
     lfs = std::numeric_limits<uint64_t>::max();
     basepath = NULL;
-    for(size_t i = 0, ei = branches_.size(); i != ei; i++)
+    for(const auto &branch : *branches_)
       {
-        branch = &branches_[i];
-
-        if(branch->ro_or_nc())
+        if(branch.ro_or_nc())
           error_and_continue(error,EROFS);
-        rv = fs::info(branch->path,&info);
+        rv = fs::info(branch.path,&info);
         if(rv == -1)
           error_and_continue(error,ENOENT);
         if(info.readonly)
           error_and_continue(error,EROFS);
-        if(info.spaceavail < branch->minfreespace())
+        if(info.spaceavail < branch.minfreespace())
           error_and_continue(error,ENOSPC);
         if(info.spaceavail > lfs)
           continue;
 
         lfs = info.spaceavail;
-        basepath = &branch->path;
+        basepath = &branch.path;
       }
 
     if(basepath == NULL)
@@ -73,26 +71,28 @@ namespace lfs
 
     return 0;
   }
-
-  static
-  int
-  create(const Branches &branches_,
-         vector<string> *paths_)
-  {
-    rwlock::ReadGuard guard(branches_.lock);
-
-    return lfs::create(branches_.vec,paths_);
-  }
 }
 
 int
-Policy::Func::lfs(const Category  type_,
-                  const Branches &branches_,
-                  const char     *fusepath_,
-                  vector<string> *paths_)
+Policy::LFS::Action::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
 {
-  if(type_ == Category::CREATE)
-    return lfs::create(branches_,paths_);
+  return Policies::Action::eplfs(branches_,fusepath_,paths_);
+}
 
-  return Policy::Func::eplfs(type_,branches_,fusepath_,paths_);
+int
+Policy::LFS::Create::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
+{
+  return ::lfs::create(branches_,paths_);
+}
+
+int
+Policy::LFS::Search::operator()(const Branches::CPtr &branches_,
+                                const char           *fusepath_,
+                                StrVec               *paths_) const
+{
+  return Policies::Search::eplfs(branches_,fusepath_,paths_);
 }
