@@ -20,9 +20,11 @@
 
 #include "wyhash.h"
 
-#include <stdint.h>
+#include <cstdint>
+
 #include <sys/time.h>
 
+
 static uint64_t G_SEED;
 static RND      G_RND;
 
